# libpythonpro
Módulo para exemplificar a construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://app.travis-ci.com/rafael-hsm/libpythonpro.svg?branch=main)](https://app.travis-ci.com/rafael-hsm/libpythonpro)
[![Updates](https://pyup.io/repos/github/rafael-hsm/libpythonpro/shield.svg)](https://pyup.io/repos/github/rafael-hsm/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/rafael-hsm/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/rafael-hsm/libpythonpro/)

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip